@@ -454,7 +454,7 @@ include(abcd.text)
 
 #[test]
 fn gammer_passed_check_1() {
-    let source = include_str!("../assert/gammar/include_check.cmake");
+    let source = include_str!("../assets_for_test/gammar/include_check.cmake");
     let mut parse = tree_sitter::Parser::new();
     parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
     let thetree = parse.parse(&source, None).unwrap();
@@ -480,7 +480,7 @@ fn gammer_passed_check_1() {
 
 #[test]
 fn gammer_passed_check_2() {
-    let source = include_str!("../assert/gammar/pass_test.cmake");
+    let source = include_str!("../assets_for_test/gammar/pass_test.cmake");
     let mut parse = tree_sitter::Parser::new();
     parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
     let thetree = parse.parse(&source, None).unwrap();
