@@ -1,14 +1,14 @@
-use std::{collections::HashMap, fs, path::PathBuf};
-
-use crate::Url;
+use std::collections::HashMap;
+use std::fs;
+use std::path::PathBuf;
 use std::sync::LazyLock;
 
-use crate::utils::{CMakePackage, CMakePackageFrom, PackageType};
-
 use super::{
-    get_available_libs, get_cmake_message, get_version, handle_config_package, CMAKECONFIG,
-    CMAKECONFIGVERSION, CMAKEREGEX, SPECIAL_PACKAGE_PATTERN,
+    CMAKECONFIG, CMAKECONFIGVERSION, CMAKEREGEX, SPECIAL_PACKAGE_PATTERN, get_available_libs,
+    get_cmake_message, get_version, handle_config_package,
 };
+use crate::Url;
+use crate::utils::{CMakePackage, CMakePackageFrom, PackageType};
 
 // here is the logic of findpackage on linux
 //
@@ -44,13 +44,8 @@ pub(super) fn get_cmake_message_with_prefixes(
                     }
                 }
             }
-            let config_file_location = tojump
-                .iter()
-                .position(|file| CMAKECONFIG.is_match(file.to_str().unwrap()))
-                .unwrap();
-            if config_file_location != 0 {
-                tojump.swap(0, config_file_location);
-            }
+
+            // NOTE: Make sure it is package first
             if !ispackage {
                 continue;
             }
@@ -65,6 +60,14 @@ pub(super) fn get_cmake_message_with_prefixes(
                 continue;
             };
 
+            let config_file_location = tojump
+                .iter()
+                .position(|file| CMAKECONFIG.is_match(file.to_str().unwrap()))
+                .unwrap();
+            if config_file_location != 0 {
+                tojump.swap(0, config_file_location);
+            }
+
             let location = Url::from_file_path(&path).unwrap();
 
             packages.insert(
