@@ -1,15 +1,14 @@
-use std::{collections::HashMap, fs, path::PathBuf};
-
+use std::collections::HashMap;
+use std::fs;
+use std::path::PathBuf;
 use std::sync::LazyLock;
 
-use crate::Url;
-
-use crate::utils::{CMakePackage, CMakePackageFrom, PackageType};
-
 use super::{
-    get_available_libs, get_cmake_message, get_version, handle_config_package, CMAKECONFIG,
-    CMAKECONFIGVERSION, CMAKEREGEX, SPECIAL_PACKAGE_PATTERN,
+    CMAKECONFIG, CMAKECONFIGVERSION, CMAKEREGEX, SPECIAL_PACKAGE_PATTERN, get_available_libs,
+    get_cmake_message, get_version, handle_config_package,
 };
+use crate::Url;
+use crate::utils::{CMakePackage, CMakePackageFrom, PackageType};
 
 // here is the logic of findpackage on linux
 //
@@ -161,7 +160,7 @@ pub static CMAKE_PACKAGES_WITHKEY: LazyLock<HashMap<String, CMakePackage>> =
 fn test_prefix() {
     use crate::utils::findpackage::CMAKE_PREFIXES;
     let prefix = "/data/data/com.termux/files/usr".to_string();
-    std::env::set_var("PREFIX", &prefix);
+    unsafe { std::env::set_var("PREFIX", &prefix) };
     let prefixes = &*CMAKE_PREFIXES;
 
     // since now we use the prefix by cmake first, so...
@@ -173,6 +172,7 @@ fn test_package_search() {
     use std::fs;
     use std::fs::File;
     use std::io::Write;
+
     use tempfile::tempdir;
     let dir = tempdir().unwrap();
 
